[−][src]Trait object_query::AccessNextMut
Describes how to access query on a mutable item
Describes how to access query on a mutable item
fn access_next_mut<'a>(&mut self, query: &Query<'a>) -> Option<&mut Self>impl AccessNextMut for Value[src]fn access_next_mut<'a>(&mut self, query: &Query<'a>) -> Option<&mut Self>[src]