pub trait QuerySet: QuerySetItem + AccessMut {
// Provided method
fn query_set<'a, I: IntoIterator<Item = &'a Query<'a>>>(
&mut self,
queries: I,
val: Self,
) -> SetResult<Self> { ... }
}Expand description
An easily implementable trait to set a value form a list of queries on a mutable item
Provided Methods
fn query_set<'a, I: IntoIterator<Item = &'a Query<'a>>>( &mut self, queries: I, val: Self, ) -> SetResult<Self>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
impl QuerySet for Value
Available on crate feature
json only.